@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2013-2018 Draios Inc dba Sysdig.
+Copyright (C) 2013-2020 Sysdig Inc.
 
 This file is part of sysdig.
 
@@ -29,11 +29,17 @@ limitations under the License.
 #include <algorithm>
 
 #include <sinsp.h>
-#include "chisel.h"
 #ifdef HAS_CAPTURE
+#ifndef WIN32
 #include "driver_config.h"
+#endif // WIN32
 #endif // HAS_CAPTURE
 #include "sysdig.h"
+#ifdef HAS_CHISELS
+#include "chisel.h"
+#include "chisel_utils.h"
+#endif
+#include "fields_info.h"
 #include "table.h"
 #include "utils.h"
 
@@ -82,7 +88,7 @@ static void usage()
 "                    Enable live capture using the specified BPF probe instead of the kernel module.\n"
 "                    The BPF probe can also be specified via the environment variable\n"
 "                    SYSDIG_BPF_PROBE. If <bpf_probe> is left empty, sysdig will\n"
-"                    try to load one from the sysdig-probe-loader script.\n"
+"                    try to load one from the scap-driver-loader script.\n"
 #ifdef HAS_CAPTURE
 " --cri <path>       Path to CRI socket for container metadata\n"
 "                    Use the specified socket to fetch data from a CRI-compatible runtime\n"
@@ -106,11 +112,15 @@ static void usage()
 "                    better with terminals like putty. Try to use this flag if you experience\n"
 "                    terminal issues like the mouse not working.\n"
 " -h, --help         Print this page\n"
+#ifndef MINIMAL_BUILD
 " -k <url>, --k8s-api=<url>\n"
 "                    Enable Kubernetes support by connecting to the API server\n"
 "                    specified as argument. E.g. \"http://admin:password@127.0.0.1:8080\".\n"
 "                    The API server can also be specified via the environment variable\n"
 "                    SYSDIG_K8S_API.\n"
+" --node-name=<url>\n"
+"                    The node name is used as a filter when requesting metadata of pods\n"
+"                    to the API server; if empty, no filter is set\n"
 " -K <bt_file> | <cert_file>:<key_file[#password]>[:<ca_cert_file>], --k8s-api-cert=<bt_file> | <cert_file>:<key_file[#password]>[:<ca_cert_file>]\n"
 "                    Use the provided files names to authenticate user and (optionally) verify the K8S API\n"
 "                    server identity.\n"
@@ -123,6 +133,7 @@ static void usage()
 "                    Note that the format of this command-line option prohibits use of files whose names contain\n"
 "                    ':' or '#' characters in the file name.\n"
 "                    Option can also be provided via the environment variable SYSDIG_K8S_API_CERT.\n"
+#endif // MINIMAL_BUILD
 " -l, --list         List all the fields that can be used in views.\n"
 " --large-environment\n"
 "                    Support environments larger than 4KiB\n"
@@ -185,7 +196,7 @@ static void add_chisel_dirs(sinsp* inspector)
 	//
 	// Add the default chisel directory statically configured by the build system
 	//
-	inspector->add_chisel_dir(SYSDIG_INSTALLATION_DIR CHISELS_INSTALLATION_DIR, false);
+	chisel_add_dir(SYSDIG_INSTALLATION_DIR CHISELS_INSTALLATION_DIR, false);
 
 	//
 	// Add the directories configured in the SYSDIG_CHISEL_DIR environment variable
@@ -198,7 +209,7 @@ static void add_chisel_dirs(sinsp* inspector)
 
 		for(uint32_t j = 0; j < user_cdirs.size(); j++)
 		{
-			inspector->add_chisel_dir(user_cdirs[j], true);
+			chisel_add_dir(user_cdirs[j], true);
 		}
 	}
 }
@@ -334,9 +345,12 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 #else
 	sinsp_table::output_type output_type = sinsp_table::OT_JSON;
 #endif
+#ifndef MINIMAL_BUILD
 	string* k8s_api = 0;
+	string* node_name = 0;
 	string* k8s_api_cert = 0;
 	string* mesos_api = 0;
+#endif // MINIMAL_BUILD
 	bool terminal_with_mouse = false;
 	bool force_tracers_capture = false;
 	bool force_term_compat = false;
@@ -355,14 +369,19 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 		{"exclude-users", no_argument, 0, 'E' },
 		{"from", required_argument, 0, 0 },
 		{"help", no_argument, 0, 'h' },
+#ifndef MINIMAL_BUILD
 		{"k8s-api", required_argument, 0, 'k'},
+		{"node-name", required_argument, 0, 'N'},
 		{"k8s-api-cert", required_argument, 0, 'K' },
+#endif // MINIMAL_BUILD
 		{"json", no_argument, 0, 'j' },
 		{"interactive", optional_argument, 0, 0 },
 		{"large-environment", no_argument, 0, 0 },
 		{"list", optional_argument, 0, 'l' },
 		{"list-views", no_argument, 0, 0},
+#ifndef MINIMAL_BUILD
 		{"mesos-api", required_argument, 0, 'm'},
+#endif // MINIMAL_BUILD
 		{"numevents", required_argument, 0, 'n' },
 		{"page-faults", no_argument, 0, 0 },
 		{"print", required_argument, 0, 'p' },
@@ -448,21 +467,28 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 				usage();
 				delete inspector;
 				return sysdig_init_res(EXIT_SUCCESS);
+#ifndef MINIMAL_BUILD
 			case 'k':
 				k8s_api = new string(optarg);
 				break;
+			case 'N':
+				node_name = new string(optarg);
+				break;
 			case 'K':
 				k8s_api_cert = new string(optarg);
 				break;
+#endif // MINIMAL_BUILD
 			case 'j':
 				output_type = sinsp_table::OT_JSON;
 				break;
 			case 'l':
 				list_flds = true;
 				break;
+#ifndef MINIMAL_BUILD
 			case 'm':
 				mesos_api = new string(optarg);
 				break;
+#endif // MINIMAL_BUILD
 			case 'n':
 				try
 				{
@@ -493,8 +519,10 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 				break;
 			case 'r':
 				infiles.push_back(optarg);
+#ifndef MINIMAL_BUILD
 				k8s_api = new string();
 				mesos_api = new string();
+#endif // MINIMAL_BUILD
 				break;
 			case 's':
 				snaplen = atoi(optarg);
@@ -539,6 +567,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 						inspector->set_large_envs(true);
 					}
 #ifdef HAS_CAPTURE
+#ifndef MINIMAL_BUILD
 					else if(optname == "cri")
 					{
 						cri_socket_path = optarg;
@@ -547,6 +576,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 					{
 						inspector->set_cri_timeout(sinsp_numparser::parsed64(optarg));
 					}
+#endif // MINIMAL_BUILD
 #endif
 					else if(optname == "logfile")
 					{
@@ -840,6 +870,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 					open_success = false;
 				}
 
+#ifndef _WIN32
 				//
 				// Starting the live capture failed, try to load the driver with
 				// modprobe.
@@ -852,7 +883,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 					{
 						if(bpf_probe.empty())
 						{
-							if(system("sysdig-probe-loader bpf"))
+							if(system("scap-driver-loader bpf"))
 							{
 								fprintf(stderr, "Unable to load the BPF probe\n");
 							}
@@ -868,13 +899,14 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 
 					inspector->open("");
 				}
-#else
+#endif // _WIN32
+#else // HAS_CAPTURE
 				//
 				// Starting live capture
 				// If this fails on Windows and OSX, don't try with any driver
 				//
 				inspector->open("");
-#endif
+#endif // HAS_CAPTURE
 
 				//
 				// Enable gathering the CPU from the kernel module
@@ -903,6 +935,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 				inspector->enable_page_faults();
 			}
 
+#ifndef MINIMAL_BUILD
 			//
 			// run k8s, if required
 			//
@@ -915,7 +948,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 						k8s_api_cert = new string(k8s_cert_env);
 					}
 				}
-				inspector->init_k8s_client(k8s_api, k8s_api_cert);
+				inspector->init_k8s_client(k8s_api, k8s_api_cert, node_name);
 				k8s_api = 0;
 				k8s_api_cert = 0;
 			}
@@ -931,7 +964,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 						}
 					}
 					k8s_api = new string(k8s_api_env);
-					inspector->init_k8s_client(k8s_api, k8s_api_cert);
+					inspector->init_k8s_client(k8s_api, k8s_api_cert, node_name);
 				}
 				else
 				{
@@ -968,6 +1001,7 @@ sysdig_init_res csysdig_init(int argc, char **argv)
 					printf("{\"progress\": 0},\n");
 				}
 			}
+#endif // MINIMAL_BUILD
 
 			//
 			// Start the capture loop
