@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2013-2018 Draios Inc dba Sysdig.
+Copyright (C) 2013-2020 Sysdig Inc.
 
 This file is part of sysdig.
 
@@ -29,14 +29,23 @@ limitations under the License.
 #include <algorithm>
 
 #include <sinsp.h>
-#include "chisel.h"
 #include "scap_open_exception.h"
 #include "sinsp_capture_interrupt_exception.h"
 #ifdef HAS_CAPTURE
+#ifndef WIN32
 #include "driver_config.h"
+#endif // WIN32
 #endif // HAS_CAPTURE
 #include "sysdig.h"
+#ifdef HAS_CHISELS
+#include "chisel.h"
+#include "chisel_utils.h"
+#include "chisel_fields_info.h"
+#endif
+#include "fields_info.h"
 #include "utils.h"
+#include "plugin.h"
+#include "plugin_utils.h"
 
 #ifdef _WIN32
 #include "win32/getopt.h"
@@ -44,9 +53,11 @@ limitations under the License.
 #else
 #include <unistd.h>
 #include <getopt.h>
+#include <termios.h>
 #endif
 
 static bool g_terminate = false;
+static bool g_plugin_input = false;
 #ifdef HAS_CHISELS
 vector<sinsp_chisel*> g_chisels;
 #endif
@@ -58,7 +69,29 @@ static void usage();
 //
 static void signal_callback(int signal)
 {
-	g_terminate = true;
+	if(g_plugin_input)
+	{
+		//
+		// Input plugins can get stuck at any point.
+		// When we are using one, check again in few seconds and force a quit
+		// if we are stuck.
+		//
+		if(g_terminate == true)
+		{
+			exit(0);
+		}
+		else
+		{
+			g_terminate = true;
+#ifndef _WIN32
+			alarm(2);
+#endif
+		}
+	}
+	else
+	{
+		g_terminate = true;
+	}
 }
 
 //
@@ -80,14 +113,14 @@ static void usage()
 "                    Enable live capture using the specified BPF probe instead of the kernel module.\n"
 "                    The BPF probe can also be specified via the environment variable\n"
 "                    SYSDIG_BPF_PROBE. If <bpf_probe> is left empty, sysdig will\n"
-"                    try to load one from the sysdig-probe-loader script.\n"
+"                    try to load one from the scap-driver-loader script.\n"
 #ifdef HAS_CHISELS
 " -c <chiselname> <chiselargs>, --chisel <chiselname> <chiselargs>\n"
 "                    run the specified chisel. If the chisel require arguments,\n"
 "                    they must be specified in the command line after the name.\n"
 " -cl, --list-chisels\n"
-"                    lists the available chisels. Looks for chisels in\n"
-"                    ./chisels, ~/.chisels and /usr/share/sysdig/chisels.\n"
+"                    lists the available chisels. Sysdig looks for chisels in the\n"
+"                    following directories: ./chisels, ~/.chisels, /usr/share/sysdig/chisels.\n"
 #endif
 " -C <file_size>, --file-size=<file_size>\n"
 "                    Before writing an event, check whether the file is\n"
@@ -152,6 +185,20 @@ static void usage()
 "                    If no data format is specified, this can be used with -W flag to\n"
 "                    create a ring buffer of events.\n"
 " -h, --help         Print this page\n"
+" -I <inputname>[:<inputargs>], --input <inputname>[:<inputargs>]\n"
+"                    (PREVIEW feature, subject to change)\n"
+"                    capture events using the plugin with name inputname, passing to the \n"
+"                    plugin the inputargs string as parameters.\n"
+"                    The format of inputargs is controller by the plugin, refer to each\n"
+"                    plugin's documentation to learn about it.\n"
+"                    The event sources available for capture vary depending on which \n"
+"                    plugins have been installed. You can list the plugins that have been \n"
+"                    loaded by using the -Il flag.\n"
+" -Il\n"
+"                    (PREVIEW feature, subject to change)\n"
+"                    lists the loaded plugins. Sysdig looks for plugins in the directories \n"
+"                    specified by ;-separated environment variable SYSDIG_PLUGIN_DIR and\n"
+"     				 in /usr/share/sysdig/plugins.\n"
 #ifdef HAS_CHISELS
 " -i <chiselname>, --chisel-info <chiselname>\n"
 "                    Get a longer description and the arguments associated with\n"
@@ -165,6 +212,9 @@ static void usage()
 "                    specified as argument. E.g. \"http://admin:password@127.0.0.1:8080\".\n"
 "                    The API server can also be specified via the environment variable\n"
 "                    SYSDIG_K8S_API.\n"
+" --node-name=<url>\n"
+"                    The node name is used as a filter when requesting metadata of pods\n"
+"                    to the API server; if empty, no filter is set\n"
 " -K <bt_file> | <cert_file>:<key_file[#password]>[:<ca_cert_file>], --k8s-api-cert=<bt_file> | <cert_file>:<key_file[#password]>[:<ca_cert_file>]\n"
 "                    Use the provided files names to authenticate user and (optionally) verify the K8S API\n"
 "                    server identity.\n"
@@ -182,6 +232,7 @@ static void usage()
 " -l, --list         List the fields that can be used for filtering and output\n"
 "                    formatting. Use -lv to get additional information for each\n"
 "                    field.\n"
+" --libs-version     Print the falcosecurity/libs version\n"
 " --large-environment\n"
 "                    Support environments larger than 4KiB\n"
 "                    When the environment is larger than 4KiB, load the whole\n"
@@ -297,6 +348,48 @@ static void usage()
     );
 }
 
+double g_last_printed_progress_pct = 0;
+char g_prg_line_buf[512] = "";
+
+inline void clean_last_progress_line()
+{
+	uint32_t j;
+
+	for(j = 0; j < strlen(g_prg_line_buf); j++)
+	{
+		g_prg_line_buf[j] = ' ';
+	}
+	g_prg_line_buf[j] = 0;
+
+	fprintf(stderr, "\r%s", g_prg_line_buf);
+}
+
+inline void output_progress(sinsp* inspector, sinsp_evt* ev)
+{
+	if(ev == NULL || (ev->get_num() % 10000 == 0))
+	{
+		string ps;
+		double progress_pct = inspector->get_read_progress_with_str(&ps);
+
+		if(progress_pct - g_last_printed_progress_pct > 0.1)
+		{
+			clean_last_progress_line();
+			if(ps == "")
+			{
+				snprintf(g_prg_line_buf, sizeof(g_prg_line_buf), "%.2lf", progress_pct);
+			}
+			else
+			{
+				snprintf(g_prg_line_buf, sizeof(g_prg_line_buf), "%s", ps.c_str());
+			}
+
+			fprintf(stderr, "\r%s", g_prg_line_buf);
+			fflush(stderr);
+			g_last_printed_progress_pct = progress_pct;
+		}
+	}
+}
+
 void print_summary_table(sinsp* inspector,
 						 vector<summary_table_entry> &summary_table,
 						 uint32_t nentries)
@@ -351,7 +444,7 @@ static void add_chisel_dirs(sinsp* inspector)
 	//
 	// Add the default chisel directory statically configured by the build system
 	//
-	inspector->add_chisel_dir(SYSDIG_INSTALLATION_DIR CHISELS_INSTALLATION_DIR, false);
+	chisel_add_dir(SYSDIG_INSTALLATION_DIR CHISELS_INSTALLATION_DIR, false);
 
 	//
 	// Add the directories configured in the SYSDIG_CHISEL_DIR environment variable
@@ -364,7 +457,7 @@ static void add_chisel_dirs(sinsp* inspector)
 
 		for(uint32_t j = 0; j < user_cdirs.size(); j++)
 		{
-			inspector->add_chisel_dir(user_cdirs[j], true);
+			chisel_add_dir(user_cdirs[j], true);
 		}
 	}
 }
@@ -503,7 +596,7 @@ static void chisels_do_timeout(sinsp_evt* ev)
 #endif
 }
 
-void handle_end_of_file(bool print_progress, sinsp_evt_formatter* formatter = NULL)
+void handle_end_of_file(sinsp* inspector, bool print_progress, bool reset_colors = false, sinsp_evt_formatter* formatter = NULL)
 {
 	string line;
 
@@ -515,13 +608,27 @@ void handle_end_of_file(bool print_progress, sinsp_evt_formatter* formatter = NU
 		cout << line << endl;
 	}
 
+	if(reset_colors) {
+		cout << "\e[00m";
+	}
+
 	//
 	// Reached the end of a trace file.
 	// If we are reporting progress, this is 100%
 	//
 	if(print_progress)
 	{
-		fprintf(stderr, "100.00\n");
+		clean_last_progress_line();
+		if(inspector == NULL)
+		{
+			fprintf(stderr, "\r100.00\n");
+		}
+		else
+		{
+			output_progress(inspector, NULL);
+			fprintf(stderr, "\n");
+		}
+
 		fflush(stderr);
 	}
 
@@ -577,6 +684,7 @@ captureinfo do_inspect(sinsp* inspector,
 	bool quiet,
 	bool json,
 	bool do_flush,
+	bool reset_colors,
 	bool print_progress,
 	sinsp_filter* display_filter,
 	vector<summary_table_entry> &summary_table,
@@ -586,7 +694,6 @@ captureinfo do_inspect(sinsp* inspector,
 	int32_t res;
 	sinsp_evt* ev;
 	string line;
-	double last_printed_progress_pct = 0;
 	uint64_t duration_start = 0;
 
 	if(json)
@@ -605,7 +712,7 @@ captureinfo do_inspect(sinsp* inspector,
 			// End of capture, either because the user stopped it, or because
 			// we reached the event count specified with -n.
 			//
-			handle_end_of_file(print_progress, formatter);
+			handle_end_of_file(inspector, print_progress, reset_colors, formatter);
 			break;
 		}
 		res = inspector->next(&ev);
@@ -619,13 +726,18 @@ captureinfo do_inspect(sinsp* inspector,
 				// Give the chisels a chance to run their timeout logic.
 				//
 				chisels_do_timeout(ev);
+
+				if(print_progress)
+				{
+					output_progress(inspector, ev);
+				}
 			}
 
 			continue;
 		}
 		else if(res == SCAP_EOF)
 		{
-			handle_end_of_file(print_progress, formatter);
+			handle_end_of_file(inspector, print_progress, reset_colors, formatter);
 			break;
 		}
 		else if(res != SCAP_SUCCESS)
@@ -634,7 +746,7 @@ captureinfo do_inspect(sinsp* inspector,
 			// Event read error.
 			// Notify the chisels that we're exiting, and then die with an error.
 			//
-			handle_end_of_file(print_progress, formatter);
+			handle_end_of_file(inspector, print_progress, reset_colors, formatter);
 			cerr << "res = " << res << endl;
 			throw sinsp_exception(inspector->getlasterr().c_str());
 		}
@@ -646,7 +758,7 @@ captureinfo do_inspect(sinsp* inspector,
 		{
 			if(ev->get_ts() - duration_start >= duration_to_tot_ns)
 			{
-				handle_end_of_file(print_progress, formatter);
+				handle_end_of_file(inspector, print_progress, reset_colors, formatter);
 				break;
 			}
 		}
@@ -654,17 +766,7 @@ captureinfo do_inspect(sinsp* inspector,
 
 		if(print_progress)
 		{
-			if(ev->get_num() % 10000 == 0)
-			{
-				double progress_pct = inspector->get_read_progress();
-
-				if(progress_pct - last_printed_progress_pct > 0.1)
-				{
-					fprintf(stderr, "%.2lf\n", progress_pct);
-					fflush(stderr);
-					last_printed_progress_pct = progress_pct;
-				}
-			}
+			output_progress(inspector, ev);
 		}
 
 		//
@@ -750,6 +852,62 @@ captureinfo do_inspect(sinsp* inspector,
 	return retval;
 }
 
+#ifndef _WIN32
+struct termios g_saved_term_attributes;
+
+void reset_tty_input_mode(void)
+{
+	tcsetattr(STDIN_FILENO, TCSANOW, &g_saved_term_attributes);
+}
+
+void disable_tty_echo() {
+	struct termios tattr;
+
+	/* Make sure stdin is a terminal. */
+	if (!isatty(STDIN_FILENO))
+	{
+		return;
+	}
+
+	/* Save the terminal attributes so we can restore them later. */
+	tcgetattr(STDIN_FILENO, &g_saved_term_attributes);
+	atexit(reset_tty_input_mode);
+
+	/* Disable terminal echo */
+	tcgetattr(STDIN_FILENO, &tattr);
+	tattr.c_lflag &= ~(ICANON|ECHO); /* Clear ICANON and ECHO. */
+	tattr.c_cc[VMIN] = 1;
+	tattr.c_cc[VTIME] = 0;
+	tcsetattr(STDIN_FILENO, TCSAFLUSH, &tattr);
+}
+#endif
+
+std::string escape_output_format(const std::string& s)
+{
+    std::stringstream  ss{""};
+
+    for(size_t i = 0; i < s.length(); i++)
+    {
+        if (s.at(i) == '\\')
+        {
+            switch(s.at(i + 1))
+            {
+                case 'n':  ss << "\n"; i++; break;
+				case 't':  ss << "\t"; i++; break;
+				case 'e':  ss << "\e"; i++; break;
+				case '\\': ss << "\\"; i++; break;
+                default:   ss << "\\";      break;
+            }
+        }
+        else
+        {
+            ss << s.at(i);
+        }
+    }
+
+    return ss.str();
+}
+
 //
 // ARGUMENT PARSING AND PROGRAM SETUP
 //
@@ -774,16 +932,19 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 	int duration_to_tot = 0;
 	captureinfo cinfo;
 	string output_format;
+	string output_format_plugin;
 	uint32_t snaplen = 0;
 	int long_index = 0;
 	int32_t n_filterargs = 0;
 	bool jflag = false;
 	bool unbuf_flag = false;
+	bool reset_colors = false;
 	bool filter_proclist_flag = false;
 	string cname;
 	vector<summary_table_entry> summary_table;
 #ifndef MINIMAL_BUILD
 	string* k8s_api = 0;
+	string* node_name = 0;
 	string* k8s_api_cert = 0;
 	string* mesos_api = 0;
 #endif // MINIMAL_BUILD
@@ -796,6 +957,8 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 	string cri_socket_path;
 #endif
 	bool udig = false;
+	string inputname;
+	bool has_src_plugin = false;
 
 	// These variables are for the cycle_writer engine
 	int duration_seconds = 0;
@@ -824,18 +987,25 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 		{"filter-proclist", no_argument, 0, 0 },
 		{"seconds", required_argument, 0, 'G' },
 		{"help", no_argument, 0, 'h' },
+		{"input", required_argument, 0, 'I' },
 #ifdef HAS_CHISELS
 		{"chisel-info", required_argument, 0, 'i' },
 #endif
 		{"file-size", required_argument, 0, 'C' },
 		{"json", no_argument, 0, 'j' },
+#ifndef MINIMAL_BUILD
 		{"k8s-api", required_argument, 0, 'k'},
+		{"node-name", required_argument, 0, 'N'},
 		{"k8s-api-cert", required_argument, 0, 'K' },
+#endif // MINIMAL_BUILD
 		{"large-environment", no_argument, 0, 0 },
 		{"list", no_argument, 0, 'l' },
 		{"list-events", no_argument, 0, 'L' },
 		{"list-markdown", no_argument, 0, 0 },
+		{"libs-version", no_argument, 0, 0},
+#ifndef MINIMAL_BUILD
 		{"mesos-api", required_argument, 0, 'm'},
+#endif // MINIMAL_BUILD
 		{"numevents", required_argument, 0, 'n' },
 		{"page-faults", no_argument, 0, 0 },
 		{"progress", required_argument, 0, 'P' },
@@ -860,7 +1030,15 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 		{0, 0, 0, 0}
 	};
 
-	output_format = "*%evt.num %evt.outputtime %evt.cpu %proc.name (%thread.tid) %evt.dir %evt.type %evt.info";
+	if (isatty(fileno(stdout)))
+	{
+		output_format = "*%evt.num %evt.outputtime %evt.cpu \e[01;32m%proc.name\e[00m (\e[01;36m%proc.pid\e[00m.%thread.tid) %evt.dir \e[01;34m%evt.type\e[00m %evt.info";
+		output_format_plugin = "*%evt.num %evt.datetime.s [%evt.pluginname] %evt.plugininfo";
+	} else
+	{
+		output_format = "*%evt.num %evt.outputtime %evt.cpu %proc.name (%thread.tid) %evt.dir %evt.type %evt.info";
+		output_format_plugin = "*%evt.num %evt.datetime.s [%evt.pluginname] %evt.plugininfo";
+	}
 
 	try
 	{
@@ -870,6 +1048,8 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 #ifdef HAS_CHISELS
 		add_chisel_dirs(inspector);
 #endif
+		add_plugin_dirs(SYSDIG_INSTALLATION_DIR);
+		register_plugins(inspector);
 
 		//
 		// Parse the args
@@ -879,7 +1059,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
                                         "C:"
                                         "dDEe:F"
                                         "G:"
-                                        "hi:jk:K:lLm:M:n:Pp:qRr:Ss:t:TU:uv"
+                                        "hI:i:jk:K:lLm:M:n:Pp:qRr:Ss:t:TU:uv"
                                         "W:"
                                         "w:xXz", long_options, &long_index)) != -1)
 		{
@@ -974,7 +1154,63 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 					goto exit;
 				}
 				break;
+			case 'I':
+				{
+					inputname = optarg;
+					if(inputname == "l")
+					{
+						std::list<sinsp_plugin::info> infos = sinsp_plugin::plugin_infos(inspector);
+						std::ostringstream os_dirs, os_info;
 
+						for(plugin_dir_info path : get_plugin_dirs()) {
+							os_dirs << path.m_dir << " ";
+						}
+
+						for(auto &info : infos)
+						{
+							os_info << "Name: " << info.name << std::endl;
+							os_info << "Description: " << info.description << std::endl;
+							os_info << "Contact: " << info.contact << std::endl;
+							os_info << "Version: " << info.plugin_version.as_string() << std::endl;
+
+							if(info.type == TYPE_SOURCE_PLUGIN)
+							{
+								os_info << "Type: source plugin" << std::endl;
+								os_info << "ID: " << info.id << std::endl;
+							}
+							else
+							{
+								os_info << "Type: extractor plugin" << std::endl;
+							}
+						}
+
+						printf("Plugin search paths are: %s\n", os_dirs.str().c_str());
+						printf("%lu Plugins Loaded:\n\n%s\n", infos.size(), os_info.str().c_str());
+						delete inspector;
+						return sysdig_init_res(EXIT_SUCCESS);
+					}
+
+					has_src_plugin = true;
+
+					size_t cpos = inputname.find(':');
+					string pgname;
+					string pgpars;
+					if(cpos != string::npos)
+					{
+						pgname = inputname.substr(0, cpos);
+						pgpars = inputname.substr(cpos + 1);
+						inspector->set_input_plugin(pgname);
+						inspector->set_input_plugin_open_params(pgpars);
+					}
+					else
+					{
+						inspector->set_input_plugin(inputname);
+					}
+
+					g_plugin_input = true;
+					//print_progress = true;
+				}
+				break;
 #ifdef HAS_CHISELS
 			// --chisel-info and -i
 			case 'i':
@@ -998,7 +1234,6 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 				}
 				break;
 #endif
-
 			case 'd':
 				is_filter_display = true;
 				break;
@@ -1012,6 +1247,9 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 			case 'k':
 				k8s_api = new string(optarg);
 				break;
+			case 'N':
+				node_name = new string(optarg);
+				break;
 			case 'K':
 				k8s_api_cert = new string(optarg);
 				break;
@@ -1102,6 +1340,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 				else
 				{
 					output_format = optarg;
+					output_format_plugin = optarg;
 				}
 
 				break;
@@ -1211,6 +1450,11 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 						delete inspector;
 						return sysdig_init_res(EXIT_SUCCESS);
 					}
+					else if (optname == "libs-version") {
+						printf("falcosecurity/libs version %s", FALCOSECURITY_LIBS_VERSION);
+						delete inspector;
+						return sysdig_init_res(EXIT_SUCCESS);
+					}
 					else if (optname == "list-chisels") {
 						vector<chisel_desc> chlist;
 						sinsp_chisel::get_chisel_list(&chlist);
@@ -1248,7 +1492,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 					}
 				}
 				break;
-            // getopt_long : '?' for an ambiguous match or an extraneous parameter
+			// getopt_long : '?' for an ambiguous match or an extraneous parameter
 			case '?':
 				delete inspector;
 				return sysdig_init_res(EXIT_FAILURE);
@@ -1280,6 +1524,15 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 			inspector->set_bpf_probe(bpf_probe);
 		}
 
+		//
+		// If we are dumping events to file, enable progress printing so we can give
+		// feedback to the user
+		//
+		if(outfile != "" && (infiles.size() != 0 || g_plugin_input == true))
+		{
+			print_progress = true;
+		}
+
 		//
 		// If -j was specified the event_buffer_format must be rewritten to account for it
 		//
@@ -1375,10 +1628,26 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 			goto exit;
 		}
 
+		output_format = escape_output_format(output_format);
+		if (output_format.find("\e") != std::string::npos)
+		{
+			reset_colors = true;
+		}
+
+#ifndef _WIN32
+		if(signal(SIGALRM, signal_callback) == SIG_ERR)
+		{
+			fprintf(stderr, "An error occurred while setting SIGALRM signal handler.\n");
+			res.m_res = EXIT_FAILURE;
+			goto exit;
+		}
+#endif
+
 		//
 		// Create the event formatter
 		//
-		sinsp_evt_formatter formatter(inspector, output_format);
+		sinsp_evt_formatter formatter(inspector,
+					      (g_plugin_input ? output_format_plugin : output_format));
 
 		//
 		// Set output buffers len
@@ -1463,7 +1732,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 #if defined(HAS_CAPTURE)
 				bool open_success = true;
 
-				if(print_progress)
+				if(print_progress && !g_plugin_input)
 				{
 					fprintf(stderr, "the -P flag cannot be used with live captures.\n");
 					res.m_res = EXIT_FAILURE;
@@ -1476,51 +1745,59 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 				}
 				else
 				{
-					try
+					if(has_src_plugin)
 					{
 						inspector->open("");
 					}
-					catch(const sinsp_exception& e)
-					{
-						open_success = false;
-					}
-				}
-				
-				//
-				// Starting the live capture failed, try to load the driver with
-				// modprobe.
-				//
-				if(!open_success)
-				{
-					open_success = true;
-
-					if(bpf)
-					{
-						if(bpf_probe.empty())
-						{
-							if(system("sysdig-probe-loader bpf"))
-							{
-								fprintf(stderr, "Unable to load the BPF probe\n");
-							}
-						}
-					}
 					else
 					{
-						if(system("modprobe " PROBE_NAME " > /dev/null 2> /dev/null"))
+						try
 						{
-							fprintf(stderr, "Unable to load the driver\n");
+							inspector->open("");
+						}
+						catch(const sinsp_exception& e)
+						{
+							open_success = false;
 						}
 					}
+#ifndef _WIN32
+					//
+					// Starting the live capture failed, try to load the driver with
+					// modprobe.
+					//
+					if(!open_success)
+					{
+						open_success = true;
 
-					inspector->open("");
+						if(bpf)
+						{
+							if(bpf_probe.empty())
+							{
+								if(system("scap-driver-loader bpf"))
+								{
+									fprintf(stderr, "Unable to load the BPF probe\n");
+								}
+							}
+						}
+						else
+						{
+							if(system("modprobe " PROBE_NAME " > /dev/null 2> /dev/null"))
+							{
+								fprintf(stderr, "Unable to load the driver\n");
+							}
+						}
+
+						inspector->open("");
+					}
+#endif // _WIN32
 				}
-#else
+#else // HAS_CAPTURE
 				//
 				// Starting live capture
 				// If this fails on Windows and OSX, don't try with any driver
 				//
 				inspector->open("");
-#endif
+#endif // HAS_CAPTURE
 
 				//
 				// Enable gathering the CPU from the kernel module
@@ -1578,7 +1855,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 						k8s_api_cert = new string(k8s_cert_env);
 					}
 				}
-				inspector->init_k8s_client(k8s_api, k8s_api_cert, verbose);
+				inspector->init_k8s_client(k8s_api, k8s_api_cert, node_name, verbose);
 				k8s_api = 0;
 				k8s_api_cert = 0;
 			}
@@ -1594,7 +1871,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 						}
 					}
 					k8s_api = new string(k8s_api_env);
-					inspector->init_k8s_client(k8s_api, k8s_api_cert, verbose);
+					inspector->init_k8s_client(k8s_api, k8s_api_cert, node_name, verbose);
 				}
 				else
 				{
@@ -1622,6 +1899,12 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 			}
 			delete mesos_api;
 			mesos_api = 0;
+#endif
+#ifndef _WIN32
+			// Sysdig does not accept user input during the inspect loop
+			// If the user stops the program with Ctrl-C disabling input would prevent the echoed ^C
+			// from messing up the output and possibly the shell line after program termination.
+			disable_tty_echo();
 #endif
 			cinfo = do_inspect(inspector,
 				cnt,
@@ -1629,6 +1912,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 				quiet,
 				jflag,
 				unbuf_flag,
+				reset_colors,
 				print_progress,
 				display_filter,
 				summary_table,
@@ -1660,23 +1944,29 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 	}
 	catch(const sinsp_capture_interrupt_exception&)
 	{
-		handle_end_of_file(print_progress);
+		handle_end_of_file(NULL, print_progress, reset_colors);
 	}
 	catch(const scap_open_exception& e)
 	{
 		cerr << e.what() << endl;
-		handle_end_of_file(print_progress);
+		handle_end_of_file(NULL, print_progress, reset_colors);
 		res.m_res = e.scap_rc();
 	}
-	catch (const std::runtime_error& e) 
+	catch(const sinsp_exception& e)
 	{
 		cerr << e.what() << endl;
-		handle_end_of_file(print_progress);
+		handle_end_of_file(NULL, print_progress, reset_colors);
+		res.m_res = EXIT_FAILURE;
+	}
+	catch (const std::runtime_error& e)
+	{
+		cerr << e.what() << endl;
+		handle_end_of_file(NULL, print_progress, reset_colors);
 		res.m_res = EXIT_FAILURE;
 	}
 	catch(...)
 	{
-		handle_end_of_file(print_progress);
+		handle_end_of_file(NULL, print_progress, reset_colors);
 		res.m_res = EXIT_FAILURE;
 	}
 
